@@ -42,9 +42,9 @@ class Interface(object):
             Параметры:
                 angles (tuple[float, float, float]):
                     Кортеж с углами ориентации устройства.
-                    Формат: (pitch, roll, yaw)
-                    pitch (x) — наклон вперёд/назад (градусы, диапазон -180..180)
-                    roll (y) — наклон влево/вправо (градусы, диапазон -180..180)
+                    Формат: (roll, pitch, yaw)
+                    pitch (y) — наклон вперёд/назад (градусы, диапазон -180..180)
+                    roll (x) — наклон влево/вправо (градусы, диапазон -180..180)
                     yaw (z)  — поворот вокруг оси Z (градусы, диапазон -180..180)
 
                 fingers (tuple[int | float, int | float, int | float, int | float]):
@@ -107,7 +107,7 @@ class Interface(object):
         x_str = f"{round(angles[0]):<3}"
         y_str = f"{round(angles[1]):<3}"
         z_str = f"{round(angles[2]):<3}"
-        final_string = f"X:{x_str} Y:{y_str} Z:{z_str}"
+        final_string = f"X: {x_str} Y: {y_str} Z: {z_str}"
 
         self._draw.text((3, -2), final_string, fill=1, font=self._font)
 
